lilypondfiletools.ContextBlock
==============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock

.. autoclass:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.accepts_commands
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.alias
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.consists_commands
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.items
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.name
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.remove_commands
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.source_context_name
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.type_
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__eq__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__format__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__getitem__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__hash__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__ne__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__repr__

Bases
-----

- :py:class:`lilypondfiletools.Block <abjad.tools.lilypondfiletools.Block.Block>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.accepts_commands
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.alias
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.consists_commands
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.items
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.name
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.remove_commands
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.source_context_name
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.type_
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__repr__
   :noindex:
